@@ -287,6 +287,9 @@ import_delim <- function(file, which = 1, sep = "auto", header = "auto", strings
     .remap_tidy_convention(readxl::read_xlsx, file = file, which = which, header = header, ...)
 }
 
+#' @export
+.import.rio_xlsm <- .import.rio_xlsx
+
 #' @export
 .import.rio_fortran <- function(file, which = 1, style, ...) {
     if (missing(style)) {
@@ -422,3 +425,9 @@ extract_html_row <- function(x, empty_value) {
     .check_pkg_availability("qs")
     .docall(qs::qread, ..., args = list(file = file))
 }
+
+#' @export
+.import.rio_qs2 <- function(file, which = 1, ...) {
+  .check_pkg_availability("qs2")
+  .docall(qs2::qs_read, ..., args = list(file = file))
+}
