@@ -49,3 +49,30 @@ test_that("Import from Excel (.xls)", {
     expect_true(is.data.frame(import("../testdata/iris.xls", sheet = 1)))
     expect_true(is.data.frame(import("../testdata/iris.xls", which = 1)))
 })
+
+test_that("Import from Excel (.xlsm)", {
+    expect_true(is.data.frame(import("../testdata/example.xlsm", sheet = 1, format = "xlsx")))
+    expect_true(is.data.frame(import("../testdata/example.xlsm", which = 1, format = "xlsx")))
+    expect_true(is.data.frame(import("../testdata/example.xlsm")))
+
+    expect_equal(
+        import_list("../testdata/example.xlsm", format = "xlsx"),
+        list(
+            Sheet1 = data.frame(A = 1),
+            Sheet2 = data.frame(B = 2)
+        )
+    )
+    expect_equal(
+        import_list("../testdata/example.xlsm"),
+        list(
+            Sheet1 = data.frame(A = 1),
+            Sheet2 = data.frame(B = 2)
+        )
+    )
+})
+
+test_that("Exporting to xlsm is not supported #469", {
+    withr::with_tempfile("iris_file", fileext = ".xlsm", code = {
+        expect_error(export(iris, iris_file), "Format not supported")
+    })
+})
